@@ -12,27 +12,41 @@ sub new {
 
 sub contratos {
     my ($self, %args) = @_;
-    my $parent = $self->{parent};
     die 'cnpj obrigatorio' unless $args{cnpj};
     $args{cnpj} =~ s/[^0-9]+//g;
     die 'cnpj invalido' unless $args{cnpj};
 
-# DOC-PATCH: as chamadas à API de contrato exigem número de contrato.
-    my $token = $parent->access_token;
-    if (!$token) {
-        my $token_res = $parent->token->autentica();
-        $token = $parent->access_token($token_res->{token});
-    }
+    my $parent = $self->{parent};
 
-    my $res = $parent->{agent}->request(
+# DOC-PATCH: as chamadas à API de contrato exigem número de contrato.
+    my $res = $parent->make_request(
+        'contrato',
         'GET',
-        $parent->{base_url} . '/v1/empresas/' . $args{cnpj} . '/contratos',
-        {
-            headers => { 'Authorization' => 'Bearer ' . $token },
-        }
+        'meucontrato/v1/empresas/' . $args{cnpj} . '/contratos',
+        {}
     );
     return $parent->parse_response($res);
-
 }
 
+sub servicos {
+    my ($self, %args) = @_;
+    die 'cnpj obrigatorio' unless $args{cnpj};
+    $args{cnpj} =~ s/[^0-9]+//g;
+    die 'cnpj invalido' unless $args{cnpj};
+
+    my $parent = $self->{parent};
+    my $contrato = $args{contrato} // $parent->{contrato};
+    die 'contrato obrigatorio' unless $contrato;
+
+# DOC-PATCH: as chamadas à API de contrato exigem número de contrato.
+    my $res = $parent->make_request(
+        'contrato',
+        'GET',
+        'meucontrato/v1/empresas/' . $args{cnpj} . '/contratos/' . $contrato . '/servicos' . ($args{servico} ? '/' . $args{servico} : ''),
+        {}
+    );
+    return $parent->parse_response($res);
+}
+
+
 1;
